package com.zanxiang.game.data.serve.pojo.dto;

import com.zanxiang.game.data.serve.pojo.base.BasePage;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import java.time.LocalDate;
import java.util.List;

/**
 * @author tianhua
 * @time 2023/9/11
 * @Description 角色充值排行榜前端查询实体
 **/
@Data
public class RoleRechargeRankingDTO extends BasePage {

    /**
     * SDK来源
     */
    @ApiModelProperty(value = "SDK来源")
    private String sourceSystem;

    /**
     * 充值开始时间
     */
    @ApiModelProperty(value = "充值开始时间")
    private LocalDate rechargeBeginDate;

    /**
     * 充值结束时间
     */
    @ApiModelProperty(value = "充值结束时间")
    private LocalDate rechargeEndDate;

    /**
     * 子游戏ID
     */
    @ApiModelProperty(value = "子游戏ID")
    private List<Long> gameId;

    /**
     * 父游戏ID
     */
    @ApiModelProperty(value = "父游戏ID")
    private List<Long> parentGameIds;

    /**
     * 超父游戏ID
     */
    @ApiModelProperty(value = "超父游戏ID")
    private Long superGameId;

    /**
     * 区服ID（列表）
     */
    @ApiModelProperty(value = "区服ID（列表）")
    private List<String> serverIds;

    /**
     * 是否合服
     */
    @ApiModelProperty(value = "是否合服：true -> 合服 ； false -> 不合服")
    private Boolean isMergeServer;

    /**
     * 角色名
     */
    @ApiModelProperty(value = "角色名")
    private String roleName;

    /**
     * 角色ID
     */
    @ApiModelProperty(value = "角色ID")
    private String roleId;

    /**
     * 角色创建时间（开始）
     */
    @ApiModelProperty(value = "角色创建时间（开始）")
    private LocalDate createRoleBeginDate;

    /**
     * 角色创建时间（结束）
     */
    @ApiModelProperty(value = "角色创建时间（结束）")
    private LocalDate createRoleEndDate;

    /**
     * 角色VIP等级
     */
    @ApiModelProperty(value = "角色VIP等级")
    private List<Long> vipLevel;

    /**
     * 邮件是否发送
     */
    @ApiModelProperty(value = "邮件是否发送: 1 -> 发送 ； 0 -> 不发送")
    private Integer isSendMail;

    /**
     * 是否转端
     */
    @ApiModelProperty(value = "是否转端: 1 -> 转端 ； 0 -> 不转端; 2-空（默认）")
    private Integer isChange;

    /**
     * 企业微信号
     */
    @ApiModelProperty(value = "企业微信号")
    private String weChatCompany;

    /**
     * 客户微信
     */
    @ApiModelProperty(value = "客户微信号")
    private String weChat;

    /**
     * 客户手机
     */
    @ApiModelProperty(value = "客户手机号")
    private String phone;

    /**
     * GS: 0-表示未操作
     */
    @ApiModelProperty(value = "GS_ID:0-表示未操作")
    private Long gsId;

    /**
     * 客服:0-表示未操作
     */
    @ApiModelProperty(value = "客服ID:0-表示未操作")
    private Long customerServerId;

    /**
     * 投手
     */
    @ApiModelProperty(value = "投手ID")
    private Long pitcherId;

    /**
     * 运营:0-表示未操作
     */
    @ApiModelProperty(value = "运营ID:0-表示未操作")
    private Long operatorId;

    /**
     * 排序字段
     */
    @ApiModelProperty(notes = "排序字段")
    private String sortFiled;

    /**
     * 排序方式：升序asc;降序desc
     */
    @ApiModelProperty(notes = "排序方式：升序asc;降序desc")
    private String sortType;

    /**
     * 角色累计充值金额最大值（单位：元）
     */
    @ApiModelProperty(notes = "角色累计充值金额最大值（单位：元）")
    private Long totalRechargeMax;

    /**
     * 角色累计充值金额最小值（单位：元）
     */
    @ApiModelProperty(notes = "角色累计充值金额最小值（单位：元）")
    private Long totalRechargeMin;

    /**
     * 是否退游
     */
    @ApiModelProperty(notes = "是否退游：1->退游;0->未退游; 2-空（默认）")
    private Integer isRemoveGame;

    /**
     * 是否退游(系统判定)
     */
    @ApiModelProperty(notes = "是否退游：1->退游;0->未退游(系统判定)")
    private Integer isRemoveGameForSystem;

    /**
     * 是否添加企微 1-是； 0-否
     */
    @ApiModelProperty(notes = "是否添加企微 1-是； 0-否; 2-空（默认）")
    private Integer isAddCorpWechat;

    /**
     * 是否唤醒 1-是；0-否
     */
    @ApiModelProperty(notes = "是否唤醒 1-是；0-否; 2-空（默认）")
    private Integer isWakeUp;

    /**
     * 玩家操作系统筛选：windows;mac;ios;devtools;android
     */
    @ApiModelProperty(notes = "玩家操作系统筛选：windows;mac;ios;devtools;android")
    private String os;


    /**
     * 创角24小时内单笔充值金额
     */
    @ApiModelProperty(value = "创角24小时内单笔充值金额")
    private Long rechargeAmountWithin24h;

    /**
     * 创角24小时内单笔充值金额范围单位
     */
    @ApiModelProperty(value = "创角24小时内单笔充值金额范围单位(>=,<=,=,<,>)")
    private String rechargeAmountWithin24hUnit = ">=";

    /**
     * 创角24小时以内累计充值金额
     */
    @ApiModelProperty(value = "创角24小时以内累计充值金额")
    private Long rechargeTotalAmountWithin24h;

    /**
     * 创角24小时以内累计充值金额范围单位
     */
    @ApiModelProperty(value = "创角24小时以内累计充值金额范围单位(>=,<=,=,<,>)")
    private String rechargeTotalAmountWithin24hUnit = ">=";

    /**
     * 角色最近活跃时间开始时间
     */
    @ApiModelProperty(value = "角色最近活跃时间开始时间")
    private LocalDate lastActiveTimeMin;

    /**
     * 角色最近活跃时间结束时间
     */
    @ApiModelProperty(value = "角色最近活跃时间结束时间")
    private LocalDate lastActiveTimeMax;


}
