package com.zanxiang.game.data.serve.task;

import com.zanxiang.game.data.serve.service.IOrderCostMonitorAlarmService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.time.LocalDateTime;

/**
 * @author ZhangXianyu
 * @version 1.0
 * @description: 表监控告警定时任务 (监控订单表、头条广告消耗表、腾讯广告消耗表)
 * @date 2024-03-20 15:25:44
 */
@Slf4j
@Component
public class OrderCostMonitorAlarmTask {

    @Resource
    private IOrderCostMonitorAlarmService  orderCostMonitorAlarmService;

    @Value("${sys-config.task_is_run}")
    private boolean run;

    /**
     * 任务每10分钟运行一次
     */
    @Scheduled(cron = "0 0/10 * * * ? ")
    public void run() {
        //本地不运行
        if(!run){
            return;
        }
        //0点0分到0点30分不执行
        LocalDateTime now = LocalDateTime.now();
        if(now.getHour() == 0 && now.getMinute() <= 30){
            return;
        }
        log.info("订单与消耗监控告警定时任务开始.");
        try {
            //监控订单表
            orderCostMonitorAlarmService.monitorDataStatus();
            //监控头条广告消耗表
            orderCostMonitorAlarmService.monitorHeadCostStatus();
            //监控腾讯广告消耗表
            orderCostMonitorAlarmService.monitorTencentCostStatus();
            log.info("订单与消耗监控告警定时任务结束.");
        } catch (Exception e) {
            log.error("定时任务订单与消耗监控告警出错", e);
        }
    }
}
